TransformSession

Struct TransformSession 

pub struct TransformSession { /* private fields */ }
A TransformSession manages the lifetime of a set of TransformContexts, performing transformations on said contexts, and extracting the results.

Sessions automatically apply appropriate transforms to navigate through nested containers, maintaining a tree of TransformContext objects representing each extraction stage.

NOTE: All sessions have a TransformSessionMode that configures the session for one of the below:

Implementations

Source

impl TransformSession

pub fn new(file_path: &Path, settings: &Settings) -> Ref<TransformSession>

Creates the new transform session for the given file_path on disk.

NOTE: The TransformSessionMode will be set to the default specified by the files.container.mode setting in the Binary Ninja global settings (not the settings passed into this function). To specify the mode, use TransformSession::new_with_mode instead.

pub fn new_with_mode( file_path: &Path, settings: &Settings, mode: TransformSessionMode, ) -> Ref<TransformSession>

Creates the new transform session for the given file_path on disk, with the specified mode.

pub fn from_view( view: &BinaryView, settings: &Settings, ) -> Ref<TransformSession>

Creates the new transform session for the given view.

pub fn from_view_with_mode( view: &BinaryView, settings: &Settings, mode: TransformSessionMode, ) -> Ref<TransformSession>

Creates the new transform session for the given view.

pub fn from_context( context: &TransformContext, settings: &Settings, mode: TransformSessionMode, ) -> Ref<TransformSession>

Creates the new transform session for the given context.

pub fn root_context(&self) -> Option<Ref<TransformContext>>

pub fn current_context(&self) -> Option<Ref<TransformContext>>

pub fn process(&self) -> ProcessResult

Process starting at the TransformSession::root_context.

See TransformSession for more information on how the different TransformSessionModes affect processing.

pub fn process_from(&self, context: &TransformContext) -> ProcessResult

Process starting at the given context.

See TransformSession for more information on how the different TransformSessionModes affect processing.

pub fn has_any_stages(&self) -> bool

Is there anything in the session to process?

Checks the root context to see if it has any possible transforms, if it does not, then that means the session will have nothing to process.

pub fn has_single_path(&self) -> bool

If the tree has a single linear path, meaning that there is only one possible sequence of contexts to process.

pub fn selected_contexts(&self) -> Array<TransformContext>

Selected contexts are the contexts that will be loaded for analysis.

Use TransformSession::set_selected_contexts to specify the contexts which to keep for further analysis.

pub fn set_selected_contexts(&self, contexts: &[Ref<TransformContext>])

Specifies the contexts which will be loaded for analysis, anything not in this list will be considered temporary and will be discarded.