pub struct Transform { /* private fields */ }Expand description
A Transform manages the decoding and encoding of data for a given format, such as a cryptographic
routine like AES, or a compression routine like LZMA.
Besides simple routines like the ones above, transforms can also be registered for “container” like
formats like ZIP, these formats are used to encapsulate multiple files or other data, and are operated
on using a TransformSession.
Implementations
Sourceimpl Transform
impl Transform
pub fn by_name(name: &str) -> Option<Self>
pub fn transform_type(&self) -> TransformType
pub fn name(&self) -> String
pub fn long_name(&self) -> String
pub fn group(&self) -> String
pub fn capabilities(&self) -> TransformCapabilities
pub fn supports_detection(&self) -> bool
pub fn supports_context(&self) -> bool
pub fn params(&self) -> Array<TransformParameterInfo>
pub fn can_decode(&self, input: &BinaryView) -> bool
pub fn decode( &self, input: &[u8], params: &TransformInputParameters, ) -> Option<DataBuffer>
pub fn encode( &self, input: &[u8], params: &TransformInputParameters, ) -> Option<DataBuffer>
pub fn decode_within_context( &self, context: &TransformContext, params: &TransformInputParameters, ) -> bool